CommandFactory

Trait CommandFactory 

pub trait CommandFactory<'a> {
    // Required method
    fn create_command(
        &self,
        args: &ArgMatches,
        logger: &'a Logger,
    ) -> TiffResult<Box<dyn Command + 'a>>;
}
Factory for creating commands from CLI arguments

This trait defines the interface for command factories which can parse CLI arguments and create the appropriate Command.

Required Methods

fn create_command( &self, args: &ArgMatches, logger: &'a Logger, ) -> TiffResult<Box<dyn Command + 'a>>

Create a new Command instance based on CLI arguments

Arguments
  • args - CLI argument matches from clap
  • logger - Logger for recording operations
Returns

A command that implements the Command trait, or an error

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors